// @ts-check
// `@type` JSDoc annotations allow editor autocompletion and type checking
// (when paired with `@ts-check`).
// There are various equivalent ways to declare your Docusaurus config.
// See: https://docusaurus.io/docs/api/docusaurus-config

import {themes as prismThemes} from 'prism-react-renderer';

var isOrekit = true;
var isRugged = !isOrekit;

/** @type {import('@docusaurus/types').Config} */

export default function configCreator() {
  return {
    title: "Orekit",
    tagline: 'An accurate and efficient core layer for space flight dynamics applications',
    favicon: 'img/white-orekit-logo.svg',

    // Set the production url of your site here
    url: 'https://your-docusaurus-site.example.com',
    // Set the /<baseUrl>/ pathname under which your site is served
    // For GitHub pages deployment, it is often '/<projectName>/'
    baseUrl: '/',

    // GitHub pages deployment config.
    // If you aren't using GitHub pages, you don't need these.
    organizationName: 'orekit.org', // Usually your GitHub org/user name.
    projectName: 'orekit', // Usually your repo name.

    onBrokenLinks: 'throw',
    onBrokenMarkdownLinks: 'warn',

    // Even if you don't use internationalization, you can use this field to set
    // useful metadata like html lang. For example, if your site is Chinese, you
    // may want to replace "en" with "zh-Hans".
    i18n: {
      defaultLocale: 'en',
      locales: ['en'],
    },

    presets: [
      [
        'classic',
        /** @type {import('@docusaurus/preset-classic').Options} */
        ({
          docs: {
            sidebarPath: './sidebars.js',
            // Please change this to your repo.
            // Remove this to remove the "edit this page" links.
            editUrl:
                'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
          },
          blog: {
            showReadingTime: true,
            // Please change this to your repo.
            // Remove this to remove the "edit this page" links.
            editUrl:
                'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
          },
          theme: {
            customCss: './src/css/custom.css',
          },
        }),
      ],
    ],

    themeConfig:
    /** @type {import('@docusaurus/preset-classic').ThemeConfig} */
        ({
          // Replace with your project's social card
          colorMode: {
            defaultMode: 'light',
            disableSwitch: true,
          },
          navbar: {
            title: 'Orekit',
            style:'primary',
            items: [
              {label: "Overview", to:"overview", position:"right"},
              {label: "News", to:"blog", position:"right"},
              {label: "Download", to:"download", position:"right"},
              {
                type: 'dropdown',
                label: 'Community',
                position: 'right',
                items: [
                  {type: 'doc', docId: 'documentation/api', label: 'API Documentation',},
                  {type: 'doc', docId: 'documentation/technical', label: 'Technical Documentation',},
                  {type: 'doc', docId: 'documentation/tutorials', label: 'Tutorials',},
                  {type: 'doc', docId: 'documentation/python_wrapper', label: 'Python wrapper Documentation',},
                ]
              },
              {
                type: 'dropdown',
                label: 'Documentation',
                position: 'right',
                items: [
                  {
                    label: 'Facebook',
                    href: 'https://www.facebook.com',
                  }
                ]
              },
              {label: "Support", to:"support", position:"right"},
              {
                href: 'https://gitlab.orekit.org/orekit/orekit',
                label: 'Githab',
                position: 'right',
              },
            ],
          },
          footer: {
            style: 'dark',
            links: [
              {
                title: 'Docs',
                items: [
                  {
                    label: 'Tutorial',
                    to: '/docs/intro',
                  },
                ],
              },
              {
                title: 'Community',
                items: [
                  {
                    label: 'Stack Overflow',
                    href: 'https://stackoverflow.com/questions/tagged/docusaurus',
                  },
                  {
                    label: 'Discord',
                    href: 'https://discordapp.com/invite/docusaurus',
                  },
                  {
                    label: 'Twitter',
                    href: 'https://twitter.com/docusaurus',
                  },
                ],
              },
              {
                title: 'More',
                items: [
                  {
                    label: 'News',
                    to: '/blog',
                  },
                  {
                    label: 'GitLab',
                    href: 'https://gitlab.orekit.org/orekit/orekit',
                  },
                ],
              },
            ],
            copyright: `Copyright © ${new Date().getFullYear()} Orekit, Inc. Built with Docusaurus.`,
          },
          prism: {
            theme: prismThemes.github,
            darkTheme: prismThemes.dracula,
          },
        }),
  };
}
