import Layout from '@theme/Layout';
import './index.css'
import React from 'react';
import Plot from 'react-plotly.js';
import './orekitUser.js'
import {
    ADSUser,
    ATVUser,
    CSGroupUser,
    EUMETSATUser,
    ExotrailUser,
    NRLUser,
    OtherUser,
    SSCUser,
    TASUser
} from "./orekitUser";

const latestOrekitVersion = "Orekit 12.0.2";

const textContent = {
    intro: `
Orekit, a low level space dynamics library written in Java, has gained widespread recognition since it was released 
under an open source license in 2008.

Space dynamics library
Orekit aims at providing accurate and efficient low level components for the development of flight dynamics 
applications. It is designed to be easily used in very different contexts, from quick studies up to critical operations.

As a library, Orekit provides basic elements (orbits, dates, attitude, frames...) and various algorithms to handle them
 (conversions, propagations, pointing...).

Java & Python APIs
Orekit is developed in Java. As Python is widely used in the scientific world, one of our awesome contributors has 
created and maintains a Python wrapper. Choose your side and enjoy!

Free (open source) software
Orekit is freely available both in source and binary formats, with all related documentation and tests.

Orekit is distributed under the Apache License version 2.0, a well known business-friendly license. This means anybody 
can use it to build any application, free or not. There are no strings attached to user code.
  `,
    space_dynamics_library : `
    Orekit aims at providing accurate and efficient low level components for the development of flight dynamics 
    applications. It is designed to be easily used in very different contexts, from quick studies up to critical 
    operations. As a library, Orekit provides basic elements (orbits, dates, attitude, frames...) and various 
    algorithms to handle them (conversions, propagations, pointing...).`,

    java_and_python_apis : `
    Orekit is developed in Java. As Python is widely used in the scientific world, one of our awesome contributors has 
    created and maintains a Python wrapper. Choose your side and enjoy!`,

    free_software : `
    Orekit is freely available both in source and binary formats, with all related documentation and tests.
    Orekit is distributed under the Apache License version 2.0, a well known business-friendly license. This means 
    anybody can use it to build any application, free or not. There are no strings attached to user code.`
};
const devContent = {

    development: "Orekit has been in development since 2002 inside CS GROUP and is still used and maintained by its space " +
        "dynamics experts. Several major actors of space research and industry are now involved into this project.\n" +
        "\n" + "This project follows the Free and Open Source Software (FOSS) development best practices identified " +
        "by the Core Infrastructure Initiative:",

    open_governance: "The Orekit project is driven according to an open governance model, involving representatives from" +
        " different space field actors in a Project Management Committee (PMC)."

}

const pmcMembers = [
    {name : "Bryan Cazabonne", company: "Airbus Defence and Space"},
    {name : "Paul Cefola", company: "University at Buffalo"},
    {name : "Frank Dreger", company: "European Space Agency"},
    {name : "Nicolas Frouvelle", company: "CS GROUP"},
    {name : "Hank Grabowski", company: "(Independent Expert"},
    {name : "Sébastien Herbinière", company: "Thales Alenia Space"},
    {name : "Petrus Hyvönen ", company: "Swedish Space Corporation"},
    {name : "Yannick Jeandroz ", company: "Airbus Defence and Space"},
    {name : "Maxime Journot", company: "CS GROUP"},
    {name : "Stéphanie Lizy-Destrez", company: "ISAE"},
    {name : "Luc Maisonobe", company: "Thales Alenia Space"},
    {name : "Romain Serra", company: "Exotrail"},
    {name : "Evan Ward ", company: "U.S. Naval Research Laboratory"},
    {name : "Pascal Parraud", company: "CS GROUP"},
    {name : "Guillermo Ortega", company: "European Space Agency"},
]

const orekitUserContent =
    [CSGroupUser,ADSUser,NRLUser,SSCUser,TASUser, ATVUser,EUMETSATUser,ExotrailUser,OtherUser];

function Plotly (){
        return (
            <div className={"Plotly"}>
            <Plot data={[
                    {
                        x: [1, 2, 3],
                        y: [2, 6, 3],
                        type: 'scatter',
                        mode: 'lines+markers',
                        marker: {color: 'red'},
                    },
                    {type: 'bar', x: [1, 2, 3], y: [2, 5, 3]},
                ]}
                layout={ {width: 600, height: 400, title: 'A Fancy Plot'}}
            /> </div>
        );
}

function Heading({text}) {
    return <h2 className="Heading">{text}</h2>;
}

function TextColumn({title, text, moreContent}) {
    return (
        <>
            <Heading text={title} />
            <div dangerouslySetInnerHTML={{__html: text}} />
            {moreContent}
        </>
    );
}

function TwoColumns({column1, column2}) {
    return (
        <div className={'TwoColumns'}>
            <div className={'column'}>{column1}</div>
            <div className={'column'}>{column2}</div>
        </div>
    )
}

function ThreeColumns({column1, column2, column3}) {
    return (
        <div className="ThreeColumns">
            <div className="column">{column1}</div>
            <div className="column">{column2}</div>
            <div className="column">{column3}</div>
        </div>
    )
}

export function Section({
                            element = 'Section',
                            children,
                            className,
                            background = 'light',
                        }) {
    const El = element;
    return (
        <El
            className={
                className
                    ? `Section ${className} ${background}`
                    : `Section ${background}`
            }>
            {children}
        </El>
    );
}

function TitledElement({title, element, subtitle}) {
    return (
        <div className="TitledElement">
            <Heading text={title} />
            <p className='subtitle'>{subtitle}</p>
            <div className='element'>{element}</div>
        </div>
    )
}

function BoxedElement({element}) {
    return (
        <div className={"BoxedElement"}>
            {element}
        </div>
    )
}

function ElementList({elementList}) {
    return (
        <div className={"ElementList"}>
            {elementList.map((element) => {return (
                <BoxedElement element={element()}/>)
            })}
        </div>
    )
}


function Banner() {
    return (
        <div className={'Banner'}>
            <div className={"group"}>
                <h1 className={"headTitle"}>Orekit</h1>
                <h2 className={"subHeadTitle"}>An accurate and efficient core layer for space flight dynamics
                    applications</h2>
                <span className={"sonarQube"}>
                    <a href="https://www.bestpractices.dev/projects/2726"><img
                        src="https://www.bestpractices.dev/projects/2726/badge"/></a>
                </span>
                <span className={"sonarQube"}>
                    <a href="https://sonar.orekit.org/dashboard?branch=master&amp;id=orekit%3Aorekit">
                        <img alt="quality gate status"
                             src="https://sonar.orekit.org/api/project_badges/measure?branch=master&amp;project=orekit%3Aorekit&amp;metric=alert_status"/>
                    </a>
                </span>
                <span className={"sonarQube"}>
                    <a href="https://sonar.orekit.org/component_measures?branch=master&amp;id=orekit%3Aorekit&amp;metric=Coverage">
                        <img alt="code coverage status"
                             src="https://sonar.orekit.org/api/project_badges/measure?branch=master&amp;project=orekit%3Aorekit&amp;metric=coverage"/>
                    </a>
                </span><br/>
                <button className={"bannerButton"}>{latestOrekitVersion} released, Get it !</button>
            </div>
        </div>
    )
}

function WhatIsIt() {
    return (
        <Section className="WhatIsIt" background="light">
            <TitledElement title={''} element={<ThreeColumns
                column1={<TextColumn title={"Space dynamics library"} text={textContent.space_dynamics_library}/>}
                column2={<TextColumn title={"Java & Python APIs"} text={textContent.java_and_python_apis}/>}
                column3={<TextColumn title={"Free (open source) software"} text={textContent.free_software}/>}
            />}/>
        </Section>);
}

function WhoIsUsingIt() {
    return (
        <Section className="WhoIsUsingIt" background="dark">
            <TitledElement title={"Trusted & Used by"} element={<ElementList elementList={orekitUserContent}/>}/>
        </Section>
    )
}

function WhoIsBehindIt() {
    // Constant
    const pmcMemberList =
        pmcMembers.map((member) => <li> {member.name} ({member.company}) </li>);


    return (
        <Section className='WhoIsBehindIt' background="light">
            <TitledElement title={""} element=
                {<TwoColumns
                    column1={<TitledElement title={"Development"} element={devContent.development}/>}
                    column2={<TitledElement title={"Open governance"} element={devContent.open_governance}/>}
                />}
            />
        </Section>
    )
}

class Index extends React.Component {
    render() {
        // const {siteConfig} = useDocusaurusContext();
        return (
            <Layout>
                <Banner/>
                <main>
                    <WhatIsIt />
                    <WhoIsUsingIt/>
                    <WhoIsBehindIt/>
                    <Plotly/>
                </main>
            </Layout>
        );
    }
}
export default Index;

// export default function Home() {
//     const {siteConfig} = useDocusaurusContext();
//     return (
//         <Layout>
//             <Banner/>
//             <main>
//                 <WhatIsIt />
//                 <Plotly/>
//                 <WhoIsUsingIt/>
//                 <WhoIsBehindIt/>
//                 <Graph/>
//             </main>
//         </Layout>
//     );
// }


